searchData={"items":[{"type":"module","title":"Html2Markdown","doc":"Convert HTML documents to clean, readable Markdown.\n\nHtml2Markdown intelligently extracts content from HTML while filtering out\nnavigation, advertisements, and other non-content elements. It's designed\nfor web scraping, content migration, and any scenario where you need to\nconvert HTML to Markdown.","ref":"Html2Markdown.html"},{"type":"module","title":"Basic Usage - Html2Markdown","doc":"iex> Html2Markdown.convert(\" Hello  World \")\n    \"# Hello\\n\\nWorld\"","ref":"Html2Markdown.html#module-basic-usage"},{"type":"module","title":"Configuration - Html2Markdown","doc":"The library supports extensive configuration through the second parameter:\n\n    Html2Markdown.convert(html, %{\n      navigation_classes: [\"nav\", \"menu\", \"sidebar\"],\n      non_content_tags: [\"script\", \"style\", \"iframe\"],\n      markdown_flavor: :basic,\n      normalize_whitespace: true\n    })","ref":"Html2Markdown.html#module-configuration"},{"type":"module","title":"Features - Html2Markdown","doc":"- **Smart filtering** - Automatically removes common non-content elements\n- **HTML5 support** - Handles modern semantic elements\n- **Table conversion** - Converts HTML tables to Markdown tables\n- **Entity decoding** - Automatically handled by Floki\n- **Whitespace normalization** - Optional cleanup of excessive whitespace\n- **Configurable** - Customize filtering behavior to your needs","ref":"Html2Markdown.html#module-features"},{"type":"module","title":"Examples - Html2Markdown","doc":"","ref":"Html2Markdown.html#module-examples"},{"type":"module","title":"Web Scraping - Html2Markdown","doc":"# Extract article content from a web page\n    {:ok, %{body: html}} = HTTPoison.get(\"https://example.com/article\")\n    \n    content = Html2Markdown.convert(html, %{\n      navigation_classes: [\"header\", \"footer\", \"nav\", \"sidebar\"],\n      normalize_whitespace: true\n    })","ref":"Html2Markdown.html#module-web-scraping"},{"type":"module","title":"Content Migration - Html2Markdown","doc":"# Convert WordPress posts to Markdown\n    post_html\n    |> Html2Markdown.convert()\n    |> File.write!(\"post.md\")","ref":"Html2Markdown.html#module-content-migration"},{"type":"module","title":"Email Processing - Html2Markdown","doc":"# Clean up HTML emails\n    email_body\n    |> Html2Markdown.convert(%{\n      non_content_tags: [\"style\", \"meta\", \"link\"],\n      navigation_classes: [\"unsubscribe\", \"footer\"]\n    })","ref":"Html2Markdown.html#module-email-processing"},{"type":"module","title":"Supported HTML Elements - Html2Markdown","doc":"","ref":"Html2Markdown.html#module-supported-html-elements"},{"type":"module","title":"Text Elements - Html2Markdown","doc":"- Headings: ` ` through ` `\n- Paragraphs: ` `\n- Emphasis: ` `, ` ` → `*italic*`\n- Strong: ` `, ` ` → `**bold**`\n- Strikethrough: ` ` → `~~strikethrough~~`\n- Code: ` ` → `` `code` ``\n- Preformatted: ` ` → ``` code blocks ```","ref":"Html2Markdown.html#module-text-elements"},{"type":"module","title":"Lists - Html2Markdown","doc":"- Unordered lists: ` `, ` ` → `- item`\n- Ordered lists: ` `, ` ` → `1. item`\n- Definition lists: ` `, ` `, ` `","ref":"Html2Markdown.html#module-lists"},{"type":"module","title":"Links and Media - Html2Markdown","doc":"- Links: ` ` → `[text](url)`\n- Images: ` ` → `![alt](src)`\n- Picture: ` ` with fallback to ` `","ref":"Html2Markdown.html#module-links-and-media"},{"type":"module","title":"Tables - Html2Markdown","doc":"Full support for HTML tables with automatic header detection:\n\n     \n        Name  Value  \n        Elixir  1.15  \n     \n\nConverts to:\n\n    | Name | Value |\n    | --- | --- |\n    | Elixir | 1.15 |","ref":"Html2Markdown.html#module-tables"},{"type":"module","title":"HTML5 Elements - Html2Markdown","doc":"- ` ` / ` ` - Collapsible sections\n- ` ` - Highlighted text (GFM: `==marked==`)\n- ` ` - Abbreviations with expansion\n- ` ` - Citations in italics\n- ` ` - Inline quotes with optional citation\n- ` ` - Time with preserved datetime\n- ` ` - Converted to markdown link","ref":"Html2Markdown.html#module-html5-elements"},{"type":"module","title":"Entity Handling - Html2Markdown","doc":"HTML entities are automatically decoded by Floki:\n- `&amp;` → `&`\n- `&lt;` → `<`\n- `&gt;` → `>`\n- `&nbsp;` → non-breaking space\n- `&#123;` → `{`\n- `&#xAB;` → `«`","ref":"Html2Markdown.html#module-entity-handling"},{"type":"type","title":"Html2Markdown.conversion_options/0","doc":"","ref":"Html2Markdown.html#t:conversion_options/0"},{"type":"function","title":"Html2Markdown.convert/1","doc":"Converts the content from an HTML document to Markdown (removing non-content sections and tags)\n\nUses default options for conversion. To customize behavior, use `convert/2`.","ref":"Html2Markdown.html#convert/1"},{"type":"function","title":"Html2Markdown.convert/2","doc":"Converts the content from an HTML document to Markdown with custom options","ref":"Html2Markdown.html#convert/2"},{"type":"function","title":"Options - Html2Markdown.convert/2","doc":"* `:navigation_classes` - List of CSS classes to identify navigation elements to remove.\n    Defaults to `[\"footer\", \"menu\", \"nav\", \"sidebar\", \"aside\"]`\n  * `:non_content_tags` - List of HTML tags to filter out during conversion.\n    Defaults to common non-content tags like script, style, form, etc.\n  * `:markdown_flavor` - Markdown flavor to use. Currently only `:basic` is supported.\n    Defaults to `:basic` (future enhancement for `:gfm`, `:commonmark`)\n  * `:normalize_whitespace` - Whether to normalize whitespace. When enabled, multiple\n    spaces/tabs are converted to single spaces and leading/trailing whitespace is trimmed.\n    Whitespace in code blocks and inline code is always preserved. Defaults to `true`","ref":"Html2Markdown.html#convert/2-options"},{"type":"function","title":"Examples - Html2Markdown.convert/2","doc":"iex> Html2Markdown.convert(\" Hello \", %{navigation_classes: [\"custom-nav\"]})\n    \"Hello\"","ref":"Html2Markdown.html#convert/2-examples"},{"type":"type","title":"Html2Markdown.html_content/0","doc":"","ref":"Html2Markdown.html#t:html_content/0"},{"type":"type","title":"Html2Markdown.markdown_content/0","doc":"","ref":"Html2Markdown.html#t:markdown_content/0"},{"type":"module","title":"Html2Markdown.Converter","doc":"Handles the conversion of HTML nodes to Markdown format.\n\nThis module is responsible for transforming parsed HTML nodes into their\nMarkdown equivalents. It uses an efficient IOList-based approach for\nbuilding the output string.","ref":"Html2Markdown.Converter.html"},{"type":"module","title":"Implementation Details - Html2Markdown.Converter","doc":"The converter uses pattern matching to handle different HTML elements:\n- Headers (`h1`-`h6`) → Markdown headers with appropriate `#` prefixes\n- Text formatting (`strong`, `em`, `del`) → Markdown emphasis markers\n- Lists (`ul`, `ol`) → Markdown list syntax with proper nesting\n- Tables → Delegated to `Html2Markdown.TableConverter`\n- Links and images → Markdown link syntax\n- Code blocks → Fenced code blocks with language detection","ref":"Html2Markdown.Converter.html#module-implementation-details"},{"type":"module","title":"Performance Optimizations - Html2Markdown.Converter","doc":"- Uses IOList building instead of string concatenation\n- Processes nodes in a single pass\n- Preserves whitespace in code blocks while normalizing elsewhere","ref":"Html2Markdown.Converter.html#module-performance-optimizations"},{"type":"function","title":"Html2Markdown.Converter.convert_to_markdown/2","doc":"","ref":"Html2Markdown.Converter.html#convert_to_markdown/2"},{"type":"function","title":"Html2Markdown.Converter.process_children/2","doc":"","ref":"Html2Markdown.Converter.html#process_children/2"},{"type":"function","title":"Html2Markdown.Converter.process_node/2","doc":"","ref":"Html2Markdown.Converter.html#process_node/2"},{"type":"module","title":"Html2Markdown.ElementTypes","doc":"Provides element type classification for HTML to Markdown conversion.\n\nThis module categorizes HTML elements into block, inline, and other types\nto enable proper spacing and formatting decisions during conversion.","ref":"Html2Markdown.ElementTypes.html"},{"type":"function","title":"Html2Markdown.ElementTypes.block_element?/1","doc":"Determines if an HTML element is a block-level element.\n\nBlock elements typically start on a new line and take up the full width\navailable. They should be separated by blank lines in markdown.","ref":"Html2Markdown.ElementTypes.html#block_element?/1"},{"type":"function","title":"Examples - Html2Markdown.ElementTypes.block_element?/1","doc":"iex> Html2Markdown.ElementTypes.block_element?(\"p\")\n    true\n\n    iex> Html2Markdown.ElementTypes.block_element?(\"span\")\n    false","ref":"Html2Markdown.ElementTypes.html#block_element?/1-examples"},{"type":"function","title":"Html2Markdown.ElementTypes.content_node?/1","doc":"Determines if an element should be treated as content.\n\nThis is used to filter out empty text nodes, comments, etc.","ref":"Html2Markdown.ElementTypes.html#content_node?/1"},{"type":"function","title":"Html2Markdown.ElementTypes.empty_content?/1","doc":"Determines if processed content is empty.\n\nUsed to filter out elements that produce no markdown output.","ref":"Html2Markdown.ElementTypes.html#empty_content?/1"},{"type":"function","title":"Html2Markdown.ElementTypes.heading_element?/1","doc":"Determines if an HTML element is a heading element.","ref":"Html2Markdown.ElementTypes.html#heading_element?/1"},{"type":"function","title":"Examples - Html2Markdown.ElementTypes.heading_element?/1","doc":"iex> Html2Markdown.ElementTypes.heading_element?(\"h1\")\n    true\n\n    iex> Html2Markdown.ElementTypes.heading_element?(\"h7\")\n    false","ref":"Html2Markdown.ElementTypes.html#heading_element?/1-examples"},{"type":"function","title":"Html2Markdown.ElementTypes.inline_element?/1","doc":"Determines if an HTML element is an inline element.\n\nInline elements flow within text and don't create line breaks.\nThey should not have extra spacing added around them.","ref":"Html2Markdown.ElementTypes.html#inline_element?/1"},{"type":"function","title":"Examples - Html2Markdown.ElementTypes.inline_element?/1","doc":"iex> Html2Markdown.ElementTypes.inline_element?(\"em\")\n    true\n\n    iex> Html2Markdown.ElementTypes.inline_element?(\"p\")\n    false","ref":"Html2Markdown.ElementTypes.html#inline_element?/1-examples"},{"type":"function","title":"Html2Markdown.ElementTypes.list_element?/1","doc":"Determines if an HTML element is a list element.","ref":"Html2Markdown.ElementTypes.html#list_element?/1"},{"type":"function","title":"Examples - Html2Markdown.ElementTypes.list_element?/1","doc":"iex> Html2Markdown.ElementTypes.list_element?(\"ul\")\n    true\n\n    iex> Html2Markdown.ElementTypes.list_element?(\"li\")\n    true\n\n    iex> Html2Markdown.ElementTypes.list_element?(\"p\")\n    false","ref":"Html2Markdown.ElementTypes.html#list_element?/1-examples"},{"type":"module","title":"Html2Markdown.Options","doc":"Handles configuration options for HTML to Markdown conversion.","ref":"Html2Markdown.Options.html"},{"type":"module","title":"Available Options - Html2Markdown.Options","doc":"- `:navigation_classes` - List of CSS classes that identify navigation elements to remove.\n  Default: `[\"footer\", \"menu\", \"nav\", \"sidebar\", \"aside\"]`\n\n- `:non_content_tags` - List of HTML tags to filter out completely.\n  Default includes tags like `script`, `style`, `iframe`, etc.\n\n- `:markdown_flavor` - The markdown variant to generate.\n  Currently only `:basic` is supported. Future versions may support `:gfm` and `:commonmark`.\n\n- `:normalize_whitespace` - Whether to collapse multiple spaces and trim whitespace.\n  Default: `true`. Code blocks always preserve whitespace regardless of this setting.","ref":"Html2Markdown.Options.html#module-available-options"},{"type":"module","title":"Examples - Html2Markdown.Options","doc":"# Use all defaults\n    options = Options.defaults()\n\n    # Merge custom options with defaults\n    custom = Options.merge(%{\n      navigation_classes: [\"custom-nav\", \"advertisement\"],\n      normalize_whitespace: false\n    })","ref":"Html2Markdown.Options.html#module-examples"},{"type":"function","title":"Html2Markdown.Options.defaults/0","doc":"Returns the default options map.","ref":"Html2Markdown.Options.html#defaults/0"},{"type":"function","title":"Html2Markdown.Options.merge/1","doc":"Merges user options with defaults.","ref":"Html2Markdown.Options.html#merge/1"},{"type":"type","title":"Html2Markdown.Options.t/0","doc":"","ref":"Html2Markdown.Options.html#t:t/0"},{"type":"module","title":"Html2Markdown.Parser","doc":"Handles HTML preprocessing and parsing operations.\n\nThis module is responsible for:\n1. Parsing HTML content using Floki\n2. Filtering out non-content elements\n3. Preparing the document tree for conversion","ref":"Html2Markdown.Parser.html"},{"type":"module","title":"Filtering Strategy - Html2Markdown.Parser","doc":"The parser removes elements in two ways:\n- **Tag-based filtering**: Removes elements like ` `, ` `, ` `\n- **Class-based filtering**: Removes elements with navigation classes like \"footer\", \"sidebar\"","ref":"Html2Markdown.Parser.html#module-filtering-strategy"},{"type":"module","title":"Performance - Html2Markdown.Parser","doc":"Uses MapSet for O(1) lookup performance when checking tags and classes.","ref":"Html2Markdown.Parser.html#module-performance"},{"type":"type","title":"Html2Markdown.Parser.html_tree/0","doc":"","ref":"Html2Markdown.Parser.html#t:html_tree/0"},{"type":"function","title":"Html2Markdown.Parser.preprocess_content/2","doc":"Preprocesses HTML content by parsing it and filtering out non-content elements.","ref":"Html2Markdown.Parser.html#preprocess_content/2"},{"type":"module","title":"Html2Markdown.TableConverter","doc":"Handles conversion of HTML tables to Markdown format.\n\nConverts HTML tables to GitHub Flavored Markdown tables with support for:\n- Header detection (from ` ` elements or ` `)\n- Complex table structures with ` ` and ` `\n- Colspan handling (content repeated across columns)\n- Empty cells and malformed tables","ref":"Html2Markdown.TableConverter.html"},{"type":"module","title":"Examples - Html2Markdown.TableConverter","doc":"# Simple table\n     \n        Name  Age  \n        Alice  30  \n     \n\n    # Converts to:\n    | Name | Age |\n    | --- | --- |\n    | Alice | 30 |","ref":"Html2Markdown.TableConverter.html#module-examples"},{"type":"module","title":"Implementation Notes - Html2Markdown.TableConverter","doc":"- Tables without headers still generate valid Markdown tables\n- Empty cells are preserved as empty columns\n- Malformed HTML is handled gracefully","ref":"Html2Markdown.TableConverter.html#module-implementation-notes"},{"type":"function","title":"Html2Markdown.TableConverter.process_table/2","doc":"","ref":"Html2Markdown.TableConverter.html#process_table/2"},{"type":"extras","title":"Html2Markdown","doc":"# Html2Markdown\n\n[![Hex.pm](https://img.shields.io/hexpm/v/html2markdown.svg)](https://hex.pm/packages/html2markdown)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-purple.svg)](https://hexdocs.pm/html2markdown)\n[![License](https://img.shields.io/hexpm/l/html2markdown.svg)](https://github.com/cpursley/html2markdown/blob/main/LICENSE)\n[![CI](https://github.com/agoodway/html2markdown/workflows/CI/badge.svg)](https://github.com/agoodway/html2markdown/actions/workflows/ci.yml)\n\nConvert HTML to clean, readable Markdown. Designed for content extraction, this library handles common HTML patterns while filtering out non-content elements like navigation and and scripts.","ref":"readme.html"},{"type":"extras","title":"Installation - Html2Markdown","doc":"Add `html2markdown` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:html2markdown, \"~> 0.3.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Quick Start - Html2Markdown","doc":"```elixir\n# Basic conversion\nHtml2Markdown.convert(\" Hello World  Welcome to  Elixir ! \")\n# => \"\\n# Hello World\\n\\n\\n\\nWelcome to **Elixir**!\\n\"\n\n# With custom options\nHtml2Markdown.convert(html, %{\n  navigation_classes: [\"nav\", \"menu\", \"custom-nav\"],\n  normalize_whitespace: true\n})\n```","ref":"readme.html#quick-start"},{"type":"extras","title":"Features - Html2Markdown","doc":"- **Smart Content Extraction**: Automatically removes navigation, ads, and other non-content elements\n- **HTML5 Support**: Handles modern semantic elements like ` `, ` `, ` `\n- **Table Conversion**: Converts HTML tables to clean Markdown tables\n- **Entity Handling**: Properly decodes HTML entities (`&amp;`, `&lt;`, `&nbsp;`, etc.)\n- **Configurable**: Customize filtering and processing behavior","ref":"readme.html#features"},{"type":"extras","title":"Configuration Options - Html2Markdown","doc":"```elixir\nHtml2Markdown.convert(html, %{\n  # CSS classes that identify navigation elements to remove\n  navigation_classes: [\"footer\", \"menu\", \"nav\", \"sidebar\", \"aside\"],\n  \n  # HTML tags to filter out during conversion\n  non_content_tags: [\"script\", \"style\", \"form\", \"nav\", ...],\n  \n  # Markdown flavor (currently :basic, future: :gfm, :commonmark)\n  markdown_flavor: :basic,\n  \n  # Normalize whitespace (collapses multiple spaces, trims)\n  normalize_whitespace: true\n})\n```","ref":"readme.html#configuration-options"},{"type":"extras","title":"Common Use Cases - Html2Markdown","doc":"","ref":"readme.html#common-use-cases"},{"type":"extras","title":"Web Scraping - Html2Markdown","doc":"Extract readable content from web pages:\n\n```elixir\n{:ok, %{body: html}} = Req.get!(url)\nmarkdown = Html2Markdown.convert(html)\n```","ref":"readme.html#web-scraping"},{"type":"extras","title":"Content Migration - Html2Markdown","doc":"Convert existing HTML content to Markdown:\n\n```elixir\n# Convert blog posts from HTML to Markdown\nhtml_content\n|> Html2Markdown.convert(%{normalize_whitespace: true})\n|> save_as_markdown()\n```","ref":"readme.html#content-migration"},{"type":"extras","title":"Email Processing - Html2Markdown","doc":"Clean up HTML emails for plain text storage:\n\n```elixir\nemail_html\n|> Html2Markdown.convert(%{\n  non_content_tags: [\"style\", \"script\", \"meta\"],\n  navigation_classes: [\"unsubscribe\", \"footer\"]\n})\n```","ref":"readme.html#email-processing"},{"type":"extras","title":"Supported Elements - Html2Markdown","doc":"- **Headings**: ` ` through ` `\n- **Text**: Paragraphs, emphasis (` `, ` `), strong (` `, ` `)\n- **Lists**: Ordered and unordered lists with nesting\n- **Links**: ` ` tags with proper URL handling\n- **Images**: ` ` and ` ` elements\n- **Code**: Both inline ` ` and block ` ` elements\n- **Tables**: Full table support with headers\n- **Quotes**: ` ` and ` ` elements\n- **HTML5**: ` `, ` `, ` `, ` `, ` `, ` `, ` `","ref":"readme.html#supported-elements"},{"type":"extras","title":"Documentation - Html2Markdown","doc":"Full documentation is available at [https://hexdocs.pm/html2markdown](https://hexdocs.pm/html2markdown).","ref":"readme.html#documentation"},{"type":"extras","title":"Development - Html2Markdown","doc":"This project includes comprehensive testing and quality assurance tools:","ref":"readme.html#development"},{"type":"extras","title":"Running Tests - Html2Markdown","doc":"```bash\n# Run all tests\nmix test\n\n# Run tests with coverage\nmix coveralls.html\n```","ref":"readme.html#running-tests"},{"type":"extras","title":"Code Quality - Html2Markdown","doc":"```bash\n# Run all quality checks (formatting, security, linting)\nmix quality\n\n# Individual checks\nmix format --check-formatted  # Code formatting\nmix credo --only warning       # Code linting\nmix sobelow --config          # Security analysis\n```","ref":"readme.html#code-quality"},{"type":"extras","title":"CI/CD - Html2Markdown","doc":"This project uses GitHub Actions for continuous integration with:\n- Multi-version testing (Elixir 1.15-1.17, OTP 25-27)\n- Code quality enforcement\n- Security scanning\n- Test coverage reporting","ref":"readme.html#ci-cd"},{"type":"extras","title":"License - Html2Markdown","doc":"MIT License - see [LICENSE](LICENSE) file for details.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}